Changes
~~~~~~~

0.4 (2015-02-26)
----------------

- `github ISSUE3 <https://github.com/acsone/pycoda/issues/3>`_:
  Globalisation lines are considered as Normal if they are not
  followed by details lines. The transaction type is now used
  to detect the details lines.


0.3 (2015-01-15)
----------------

- `github PR2 <https://github.com/acsone/pycoda/pull/2>`_:
  fix error in parseInformationRecord (@vparitskiy)


0.2 (2014-09-15)
----------------

- `github PR1 <https://github.com/acsone/pycoda/pull/1>`_:
  bugfix in exeption msg (@vparitskiy)

0.1 (2014-07-10)
----------------

- Initial implementation of the CODA reader
